User Manual — Stylist 0.3.dev1 documentation

# User Manual

Welcome to the Stylist code style checking tool.

The goal of this tool is to provide a flexible way of checking source code against a set of rules. Rather than require that you adopt a particular set of rules it aims to offer you the chance to build up the style you like.

The need to check Fortran source motivated the creation of this tool. As such Fortran is currently the only language supported but there is no reason it would not work for others.

- Installing Stylist
- Getting started
- Styles
  - Extending an Existing Style
  - Adding a New Style
- Available Rules
  - Language-agnostic Rules
  - Fortran Rules